handlers

package
v0.0.0-...-0ce34fa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 9, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	// DefaultFallbackIP is used when Host header is missing (common on mobile)
	DefaultFallbackIP = "192.168.1.193"
)

Variables

This section is empty.

Functions

func AboutHandler

func AboutHandler(c echo.Context) error

func CSSDebugHandler

func CSSDebugHandler(port string) echo.HandlerFunc

CSSDebugHandler returns a handler for CSS debugging information

func CSSTestHandler

func CSSTestHandler(c echo.Context) error

CSSTestHandler returns a handler for CSS functionality testing

func DashboardHandler

func DashboardHandler(c echo.Context) error

func HealthHandler

func HealthHandler(c echo.Context) error

func HomeHandler

func HomeHandler(c echo.Context) error

func MobileDetectHandler

func MobileDetectHandler(port string) echo.HandlerFunc

MobileDetectHandler returns a handler for mobile device detection and debugging

func NotFoundHandler

func NotFoundHandler(c echo.Context) error

func Render

func Render(ctx echo.Context, statusCode int, t templ.Component) error

Render replaces Echo's echo.Context.Render() with templ's templ.Component.Render()

func RobotsHandler

func RobotsHandler(c echo.Context) error

func ServiceWorkerHandler

func ServiceWorkerHandler(c echo.Context) error

Types

This section is empty.

Jump to