Documentation
¶
Index ¶
- Constants
- func AboutHandler(c echo.Context) error
- func CSSDebugHandler(port string) echo.HandlerFunc
- func CSSTestHandler(c echo.Context) error
- func DashboardHandler(c echo.Context) error
- func HealthHandler(c echo.Context) error
- func HomeHandler(c echo.Context) error
- func MobileDetectHandler(port string) echo.HandlerFunc
- func NotFoundHandler(c echo.Context) error
- func Render(ctx echo.Context, statusCode int, t templ.Component) error
- func RobotsHandler(c echo.Context) error
- func ServiceWorkerHandler(c echo.Context) error
Constants ¶
const (
// DefaultFallbackIP is used when Host header is missing (common on mobile)
DefaultFallbackIP = "192.168.1.193"
)
Variables ¶
This section is empty.
Functions ¶
func AboutHandler ¶
func CSSDebugHandler ¶
func CSSDebugHandler(port string) echo.HandlerFunc
CSSDebugHandler returns a handler for CSS debugging information
func CSSTestHandler ¶
CSSTestHandler returns a handler for CSS functionality testing
func DashboardHandler ¶
func HealthHandler ¶
func HomeHandler ¶
func MobileDetectHandler ¶
func MobileDetectHandler(port string) echo.HandlerFunc
MobileDetectHandler returns a handler for mobile device detection and debugging
func NotFoundHandler ¶
func RobotsHandler ¶
func ServiceWorkerHandler ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.